On Sat, 9 Dec 2000, Sentient Real Time Systems Ltd wrote:

> In the svgalib config file
> 
>       /etc/vga/libvga.config
> 
> add the setting
> 
>       chipset FBDev
> 
> put this in the section that contains the other
> chipset definition such as "chipset VGA". Ensure
> that no other chipset is selected (they should all
> be commented out with a # char as the first char
> of the line). I have done this and been able to
> run X (using the frame buffer device driver) and
> SVGALIB on a notebook with an otherwise unsupported
> S3 chipset.
> 
> 
> Matan :
>       Could you please add "chipset FBDev" to
>       "libvga.config" in the standard svgalib
>       distribution package. This took me an age to
>       figer out and would help newbies since they
>       could just uncomment the setting and try it
>       without understanding much about svgalib
>       itself.

This of course is still only in the pre-1.4.3 series. I had to apply the
following patch to get it to work - that means: no segmentation fault - on
my silly vesafb (I use the native sis driver otherwise).

--- src/vga.c.orig      Sat Dec  9 15:28:30 2000
+++ src/vga.c   Sat Dec  9 15:29:50 2000
@@ -988,10 +988,10 @@
     __svgalib_open_devconsole();

     /* color or monochrome text emulation? */
-    if (CHIPSET != EGA && !__svgalib_novga)
+    if (CHIPSET != EGA && CHIPSET != FBDEV && !__svgalib_novga)
        color_text = port_in(MIS_R) & 0x01;
     else
-       color_text = 1;         /* EGA is assumed color */
+       color_text = 1;         /* EGA and FBDEV are assumed color */

     /* chose registers for color/monochrome emulation */
     if (color_text) {

And I could play DOOM on the framebuffer, though slowly because of the
fixed 1024x768 resolution and sometimes it is shifted to above: maybe a
problem with the back-scroll buffer.

Bart


------------------------------------------------------------------
Unsubscribe:  To:   [EMAIL PROTECTED]
              Body: unsubscribe linux-svgalib

Reply via email to